@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: iso-8859-1 -*-
 # copyright 2002-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
@@ -23,38 +22,39 @@
 Example problem with intervals
 """
 
-from __future__ import generators
 
-from logilab.constraint import *
-from logilab.constraint.distributors import *
+from logilab.constraint import Repository, Solver, fi
 
-def intervals(size=5,verbose=0):
+
+def intervals(size=5, verbose=0):
     variables = []
     domains = {}
     constraints = []
     for i in range(size):
-        name = 'v%02d'%i
+        name = "v%02d" % i
         variables.append(name)
-        domains[name] = fi.FiniteIntervalDomain(0, size*5, 5)
+        domains[name] = fi.FiniteIntervalDomain(0, size * 5, 5)
 
     for i, q1 in enumerate(variables):
-        if i+1 == len(variables):
+        if i + 1 == len(variables):
             continue
-        q2 = variables[i+1]
+        q2 = variables[i + 1]
         c = fi.StartsAfterEnd(q1, q2)
         constraints.append(c)
 
-##     print domains
-##     print constraints
-    r = Repository(variables,domains,constraints)
-    for sol in Solver(fi.FiniteIntervalDistributor()).solve_all(r,verbose):
-        yield sol
+    #     print domains
+    #     print constraints
+    r = Repository(variables, domains, constraints)
+    yield from Solver(fi.FiniteIntervalDistributor()).solve_all(r, verbose)
+
+
+def main(args=None):
+    import sys
+    import getopt
 
-def main(args = None):
-    import sys,getopt
     if args is None:
         args = sys.argv[1:]
-    opts,args = getopt.getopt(args,'dvf')
+    opts, args = getopt.getopt(args, "dvf")
     display = 0
     verbose = 0
     first = 0
@@ -62,28 +62,29 @@ def main(args = None):
         size = int(args[0])
     else:
         size = 8
-    for o,v in opts:
-        if o == '-d':
+    for o, v in opts:
+        if o == "-d":
             display = 1
-        elif o == '-v':
+        elif o == "-v":
             verbose += 1
         elif o == "-f":
             first = 1
     count = 0
-    for sol in intervals(size,verbose):
+    for sol in intervals(size, verbose):
         count += 1
         if display:
-            print sol
-            print '*'*80
+            print(sol)
+            print("*" * 80)
         if first:
             break
     if not display:
-        print 'Use -d option to display solutions'
-    print count,'solutions found.'
+        print("Use -d option to display solutions")
+    print(count, "solutions found.")
 
-if __name__ == '__main__':
-##     import hotshot
-##     p = hotshot.Profile('/tmp/queens.prof')
-##     p.runcall(main)
-##     p.close()
+
+if __name__ == "__main__":
+    #     import hotshot
+    #     p = hotshot.Profile('/tmp/queens.prof')
+    # p.runcall(main)
+    # p.close()
     main()
