@@ -41,8 +41,7 @@ class DistinctDigits(BasicConstraint):
         return 1
 
     def __repr__(self):
-
-        return "<DistinctDigits on variable %s>" % self._variable
+        return f"<DistinctDigits on variable {self._variable}>"
 
 
 def menza():
@@ -89,6 +88,6 @@ if __name__ == "__main__":
         s.append(sol)
         if display:
             sol["c"] = sol["a"] * sol["b"]
-            print("%(a)s x %(b)s = %(c)s" % sol)
+            print(f"{sol['a']} x {sol['b']} = {sol['c']}")
     if not display:
-        print("Found %d solutions" % len(s))
+        print(f"Found {len(s)} solutions")
