@@ -40,7 +40,7 @@ class DistinctDigits(BasicConstraint):
                         domain.removeValue(v)
                         break
         except ConsistencyFailure:
-            raise ConsistencyFailure("inconsistency while applying %s" % repr(self))
+            raise ConsistencyFailure(f"inconsistency while applying {repr(self)}")
         return 1
 
     def __repr__(self):
@@ -96,6 +96,6 @@ if __name__ == "__main__":
         s.append(sol)
         if display:
             sol["c"] = sol["x"] * sol["y"]
-            print("%(x)s x %(y)s = %(c)s" % sol)
+            print(f"{sol['x']} x {sol['y']} = {sol['c']}")
     if not display:
-        print("Found %d solutions" % len(s))
+        print(f"Found {len(s)} solutions")
