@@ -1,4 +1,4 @@
-# copyright 2002-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2002-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-constraint.
@@ -16,20 +16,22 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-constraint. If not, see <http://www.gnu.org/licenses/>.
 
+
 def menza():
     sol = []
     all_digits = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"]
-    for a in range(1000) :
-        for b in range(100) :
-            c = a*b
+    for a in range(1000):
+        for b in range(100):
+            c = a * b
             if c > 9999:
                 digits = list("%.3d%.2d%.5d" % (a, b, c))
                 digits.sort()
-                if digits == all_digits :
-                    sol.append({'a': a, 'b': b})
-                    print "%.3d x %.2d = %.5d" % (a, b, c)
+                if digits == all_digits:
+                    sol.append({"a": a, "b": b})
+                    print("%.3d x %.2d = %.5d" % (a, b, c))
     return sol
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     sol = menza()
-    print len(sol)
+    print(len(sol))
