@@ -108,7 +108,7 @@ def main(args=None):
                 distrib = v
             else:
                 raise RuntimeError(
-                    "Distributor must be one of %s" % ", ".join(distributors.keys())
+                    f"Distributor must be one of {', '.join(distributors.keys())}"
                 )
 
     count = 0
