@@ -17,7 +17,12 @@
 # with logilab-constraint. If not, see <http://www.gnu.org/licenses/>.
 """Constraint Satisfaction Problem (CSP) Solver in Python."""
 
-import pkg_resources
+import sys
+
+if sys.version_info < (3, 10):
+    from importlib_metadata import version
+else:
+    from importlib.metadata import version
 
 from logilab.constraint.propagation import Repository, Solver
 from logilab.constraint.distributors import DefaultDistributor
@@ -25,4 +30,4 @@ from logilab.constraint import fd
 from logilab.constraint import fi
 
 __all__ = ["Repository", "Solver", "DefaultDistributor", "fd", "fi"]
-__version__ = pkg_resources.get_distribution("logilab-constraint").version
+__version__ = version("logilab-constraint")
