@@ -479,10 +479,10 @@ class DistributorTC(TestCase):
             "v2": d2,
         }
         dom1, dom2 = self.d.distribute(domains)
-        self.assertTrue(dom1["v2"] == dom2["v2"])
-        self.assertTrue(dom1["v2"] == d2)
-        self.assertFalse(dom1["v1"] == d1)
-        self.assertFalse(dom2["v1"] == d1)
+        self.assertEqual(dom1["v2"], dom2["v2"])
+        self.assertEqual(dom1["v2"], d2)
+        self.assertNotEqual(dom1["v1"], d1)
+        self.assertNotEqual(dom2["v1"], d1)
         self.assertEqual(dom1["v1"]._max_length, d1._min_length)
         self.assertEqual(dom2["v1"]._min_length, d1._min_length + d1._resolution)
         self.assertEqual(d1.size(), dom1["v1"].size() + dom2["v1"].size())
@@ -495,10 +495,10 @@ class DistributorTC(TestCase):
             "v2": d2,
         }
         dom1, dom2 = self.d.distribute(domains)
-        self.assertTrue(dom1["v2"] == dom2["v2"])
-        self.assertTrue(dom1["v2"] == d2)
-        self.assertFalse(dom1["v1"] == d1)
-        self.assertFalse(dom2["v1"] == d1)
+        self.assertEqual(dom1["v2"], dom2["v2"])
+        self.assertEqual(dom1["v2"], d2)
+        self.assertNotEqual(dom1["v1"], d1)
+        self.assertNotEqual(dom2["v1"], d1)
         self.assertEqual(dom1["v1"].size(), 1)
         self.assertEqual(dom1["v1"].highestMax, d1._min_length + d1.lowestMin)
         self.assertEqual(dom2["v1"].lowestMin, d1._resolution + d1.lowestMin)
